# coding=utf-8

RPC_REPLY_QUEUE_TEMPLATE = 'rpc.reply-{}-{}'
RPC_REPLY_QUEUE_TTL = 300000  # ms (5 mins)
RPC_EXCHANGE_CONFIG_KEY = 'rpc_exchange'
RPC_EXCHANGE_NAME = 'nameko-rpc'

DEFAULT_TIMEOUT = 30
DEFAULT_CON_TIMEOUT = 3
